import java.io.IOException;
import java.nio.file.*;
import java.nio.file.attribute.BasicFileAttributes;
import java.util.HashMap;
import java.util.Map;

public class Main {
    /**
     * Функция для проверки аргументов командной строки
     *
     * @param args аргументы командной строки
     * @return true, если мы корректно передали неообходимые аргументы,
     * и false в противном случае
     */
    private static boolean checkArgs(String[] args) {
        /* Проверяем что программе передан путь к файлу */
        if (args.length == 0) {
            System.out.println("Введите путь до папки");
            return false;
        }

        String dirName = args[0];
        Path dir = Paths.get(dirName);

        /* Проверяем наличие папки на диске */
        if (Files.notExists(dir)) {
            System.out.println("Данной папки не существует");
            return false;
        }

        return true;
    }

    /**
     * Функция для вывода информации по расширениям файлов
     *
     * @param counter Контейнер, содержащий информацию по расширениям файлов
     */
    private static void printExpansionsCount(Map<String, Integer> counter) {
        if (counter.size() == 0) {
            System.out.println("В данной папке нет файлов");
            return;
        }
        System.out.println("В данной папке существуют файлы со следующими расширениями");
        for (Map.Entry<String, Integer> entry : counter.entrySet()) {
            System.out.println(entry.getKey() + ": " + entry.getValue());
        }
    }

    private static void solve(String[] args) throws IOException {
        String dirName = args[0];
        Path dir = Paths.get(dirName);

        Map<String, Integer> counter = new HashMap<>();

        Files.walkFileTree(dir, new SimpleFileVisitor<Path>() {
            @Override
            public FileVisitResult visitFile(Path file, BasicFileAttributes attrs) throws IOException {
                /* Если мы посетили очередной файл, то получаем его имя */
                String fileName = file.getFileName().toString();

                /* Проверяем есть ли у него расширение */
                if (fileName.indexOf('.') != -1) {
                    /* Если есть, то получаем расширение */
                    String expansion = fileName.substring(fileName.indexOf('.') + 1, fileName.length());
                    /* Изменяет счетчик количества этого расширения */
                    int count = counter.getOrDefault(expansion, 0);
                    counter.put(expansion, count + 1);
                }
                return FileVisitResult.CONTINUE;
            }
        });

        /* Выводим информацию по расширениям файлов */
        printExpansionsCount(counter);
    }

    public static void main(String[] args) throws IOException {
        /* Проверяем аргументы командной строки */
        if (checkArgs(args)) {
            solve(args);
        }
    }
}
